@@ -292,9 +292,7 @@ def shp2df(shplist, index=None, index_dtype=None, clipto=[], filter=None,
                 # shp_df will only have a geometry column if it isn't empty
                 else:
                     geoms = shp_df.geometry.tolist()
-                    if geoms.count(None) == 0:
-                        shp_df['geometry'] = [shape(g) for g in geoms]
-                    elif skip_empty_geom:
+                    if skip_empty_geom:
                         null_geoms = [i for i, g in enumerate(geoms) if g is None]
                         shp_df.drop(null_geoms, axis=0, inplace=True)
                         shp_df['geometry'] = [shape(g) for g in shp_df.geometry.tolist()]
